@@ -4,11 +4,11 @@ apclusterDemo <- function(l=100, d=2, seed=NA, ...)
 
     if (round(l) != l || l < 2)
     {
-        stop("l must be an integer at least as large as 2.")
+        stop("l must be an integer at least as large as 2")
     }
     else if (round(d) != d || d < 1)
     {
-        stop("d must be an integer at least as large as 1.")
+        stop("d must be an integer at least as large as 1")
     }
 
     x <- matrix(runif(l * d), c(l, d))
